@@ -1,6 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketEscalationView.pm - status for all open tickets
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: AgentTicketEscalationView.pm,v 1.16.2.2 2012/08/17 09:15:51 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +14,9 @@ package Kernel::Modules::AgentTicketEscalationView;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.16.2.2 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -135,7 +140,7 @@ sub Run {
     );
 
     my %NavBarFilter;
-    for my $Filter ( sort keys %Filters ) {
+    for my $Filter ( keys %Filters ) {
         my @ViewableTickets = $Self->{TicketObject}->TicketSearch(
             %{ $Filters{$Filter}->{Search} },
             Result => 'ARRAY',
