@@ -2,7 +2,7 @@
 # Kernel/Output/HTML/LayoutTicket.pm - provides generic ticket HTML output
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: LayoutTicket.pm,v 1.141 2012/02/03 18:30:00 cr Exp $
+# $Id: LayoutTicket.pm,v 1.141.2.3 2012/11/22 09:24:52 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.141 $) [1];
+$VERSION = qw($Revision: 1.141.2.3 $) [1];
 
 sub AgentCustomerViewTable {
     my ( $Self, %Param ) = @_;
@@ -107,7 +107,10 @@ sub AgentCustomerViewTable {
                 if ( $Field->[8] ) {
                     $Record{LinkStart} .= " target=\"$Field->[8]\"";
                 }
-                $Record{LinkStart} .= "\">";
+                if ( $Field->[9] ) {
+                    $Record{LinkStart} .= " class=\"$Field->[9]\"";
+                }
+                $Record{LinkStart} .= ">";
                 $Record{LinkStop} = "</a>";
             }
             if ( $Field->[0] ) {
@@ -207,7 +210,7 @@ sub AgentQueueListOption {
             $Self->FatalError();
         }
         $Param{OnChange}
-            = "Core.AJAX.FormUpdate($('#"
+            = "Core.AJAX.FormUpdate(\$('#"
             . $Param{Name} . "'), '"
             . $Param{Ajax}->{Subaction} . "',"
             . " '$Param{Name}',"
