@@ -1,8 +1,8 @@
 # --
 # Kernel/System/CustomerUser.pm - some customer user functions
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: CustomerUser.pm,v 1.61 2010/10/04 21:38:21 mb Exp $
+# $Id: CustomerUser.pm,v 1.63.2.1 2012/06/28 21:55:42 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::CustomerCompany;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.61 $) [1];
+$VERSION = qw($Revision: 1.63.2.1 $) [1];
 
 =head1 NAME
 
@@ -119,7 +119,9 @@ sub new {
 
 return customer source list
 
-    my %List = $CustomerUserObject->CustomerSourceList();
+    my %List = $CustomerUserObject->CustomerSourceList(
+        ReadOnly => 0 # optional, 1 returns only RO backends, 0 returns writable, if not passed returns all backends
+    );
 
 =cut
 
@@ -127,11 +129,20 @@ sub CustomerSourceList {
     my ( $Self, %Param ) = @_;
 
     my %Data;
+    SOURCE:
     for my $Count ( '', 1 .. 10 ) {
 
         # next if customer backend is not used
-        next if !$Self->{ConfigObject}->Get("CustomerUser$Count");
-
+        next SOURCE if !$Self->{ConfigObject}->Get("CustomerUser$Count");
+        if ( defined $Param{ReadOnly} ) {
+            my $CustomerBackendConfig = $Self->{ConfigObject}->Get("CustomerUser$Count");
+            if ( $Param{ReadOnly} ) {
+                next SOURCE if !$CustomerBackendConfig->{ReadOnly};
+            }
+            else {
+                next SOURCE if $CustomerBackendConfig->{ReadOnly};
+            }
+        }
         $Data{"CustomerUser$Count"} = $Self->{ConfigObject}->Get("CustomerUser$Count")->{Name}
             || "No Name $Count";
     }
@@ -274,6 +285,8 @@ get user data (UserLogin, UserFirstname, UserLastname, UserEmail, ...)
 sub CustomerUserDataGet {
     my ( $Self, %Param ) = @_;
 
+    return if !$Param{User};
+
     for my $Count ( '', 1 .. 10 ) {
 
         # next if customer backend is not used
@@ -391,7 +404,7 @@ sub CustomerUserUpdate {
     }
 
     # check for UserLogin-renaming and if new UserLogin already exists...
-    if ( $Param{ID} && ( $Param{UserLogin} ne $Param{ID} ) ) {
+    if ( $Param{ID} && ( lc $Param{UserLogin} ne lc $Param{ID} ) ) {
         my %User = $Self->CustomerUserDataGet( User => $Param{UserLogin} );
         if (%User) {
             $Self->{LogObject}->Log(
@@ -681,6 +694,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.61 $ $Date: 2010/10/04 21:38:21 $
+$Revision: 1.63.2.1 $ $Date: 2012/06/28 21:55:42 $
 
 =cut
