@@ -2,7 +2,7 @@
 # Kernel/System/Ticket/ArticleStorageFS.pm - article storage module for OTRS kernel
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: ArticleStorageFS.pm,v 1.77.2.4 2012-12-03 18:24:51 mg Exp $
+# $Id: ArticleStorageFS.pm,v 1.79.2.2 2012/12/03 18:24:34 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,11 +18,13 @@ use File::Path qw();
 use MIME::Base64 qw();
 use Time::HiRes qw();
 
+use Kernel::System::VariableCheck qw(:all);
+
 # to get it writable for the otrs group (just in case)
 umask 002;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.77.2.4 $) [1];
+$VERSION = qw($Revision: 1.79.2.2 $) [1];
 
 sub ArticleStorageInit {
     my ( $Self, %Param ) = @_;
@@ -68,6 +70,27 @@ sub ArticleDelete {
         }
     }
 
+    my $DynamicFieldListArticle = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        ObjectType => 'Article',
+        Valid      => 0,
+    );
+
+    # delete dynamicfield values for this article
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{$DynamicFieldListArticle} ) {
+
+        next DYNAMICFIELD if !$DynamicFieldConfig;
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+        next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+        next DYNAMICFIELD if !IsHashRefWithData( $DynamicFieldConfig->{Config} );
+
+        $Self->{DynamicFieldBackendObject}->ValueDelete(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            ObjectID           => $Param{ArticleID},
+            UserID             => $Param{UserID},
+        );
+    }
+
     # delete index
     $Self->ArticleIndexDelete(
         ArticleID => $Param{ArticleID},
@@ -187,8 +210,7 @@ sub ArticleDeleteAttachment {
         }
     }
 
-    # return if only delete in my backend...
-    # it is for moving attachments form one backend to the other one
+    # return if only delete in my backend
     return 1 if $Param{OnlyMyBackend};
 
     # delete attachments from db
@@ -677,7 +699,7 @@ sub ArticleAttachment {
 
         # decode attachment if it's e. g. a postgresql backend!!!
         if ( !$Self->{DBObject}->GetDatabaseFunction('DirectBlob') ) {
-            $Data{Content} = decode_base64( $Row[1] );
+            $Data{Content} = MIME::Base64::decode_base64( $Row[1] );
         }
         else {
             $Data{Content} = $Row[1];
