@@ -2,7 +2,7 @@
 # Kernel/System/TicketSearch.pm - all ticket search functions
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: TicketSearch.pm,v 1.12 2012/01/27 14:20:58 mg Exp $
+# $Id: TicketSearch.pm,v 1.13.2.4 2012/10/09 07:36:30 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.12 $) [1];
+$VERSION = qw($Revision: 1.13.2.4 $) [1];
 
 use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
@@ -366,7 +366,13 @@ sub TicketSearch {
 
     # Only fetch DynamicField data if a field was requested for searching or sorting
     my $ParamCheckString = ( join '', keys %Param ) || '';
-    $ParamCheckString .= $Param{SortBy} || '';
+
+    if ( ref $Param{SortBy} eq 'ARRAY' ) {
+        $ParamCheckString .= ( join '', @{ $Param{SortBy} } );
+    }
+    elsif ( ref $Param{SortBy} ne 'HASH' ) {
+        $ParamCheckString .= $Param{SortBy} || '';
+    }
 
     if ( $ParamCheckString =~ m/DynamicField_/smx ) {
 
@@ -768,17 +774,26 @@ sub TicketSearch {
         my @CustomerIDs = $Self->{CustomerUserObject}->CustomerIDs(
             User => $Param{CustomerUserID},
         );
+
         if (@CustomerIDs) {
-            $SQLExt .= 'LOWER(st.customer_id) IN (';
+
+            my $Lower = '';
+            if ( !$Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+                $Lower = 'LOWER';
+            }
+
+            $SQLExt .= "$Lower(st.customer_id) IN (";
             my $Exists = 0;
+
             for (@CustomerIDs) {
+
                 if ($Exists) {
                     $SQLExt .= ', ';
                 }
                 else {
                     $Exists = 1;
                 }
-                $SQLExt .= "LOWER('" . $Self->{DBObject}->Quote($_) . "')";
+                $SQLExt .= "$Lower('" . $Self->{DBObject}->Quote($_) . "')";
             }
             $SQLExt .= ') OR ';
         }
@@ -1588,7 +1603,7 @@ sub TicketSearch {
             Type => 'TicketSearch',
             Key  => $SQLSelect . $SQLFrom . $SQLExt . $Result . $Limit,
         );
-        if ($CacheData) {
+        if ( defined $CacheData ) {
             if ( ref $CacheData eq 'HASH' ) {
                 return %{$CacheData};
             }
@@ -1718,6 +1733,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.12 $ $Date: 2012/01/27 14:20:58 $
+$Revision: 1.13.2.4 $ $Date: 2012/10/09 07:36:30 $
 
 =cut
